@@ -6,16 +6,15 @@ import Control.Monad as X
 import Control.Monad.IfElse as X
 import Control.Applicative as X
 import "mtl" Control.Monad.State.Strict as X (liftIO)
-import Control.Exception.Extensible as X (IOException)
 
 import Data.Maybe as X
 import Data.List as X hiding (head, tail, init, last)
 import Data.String.Utils as X hiding (join)
+import Data.Monoid as X
 
 import System.FilePath as X
 import System.Directory as X
 import System.IO as X hiding (FilePath)
-import System.PosixCompat.Files as X
 #ifndef mingw32_HOST_OS
 import System.Posix.IO as X
 #endif
@@ -31,5 +30,6 @@ import Utility.Monad as X
 import Utility.Data as X
 import Utility.Applicative as X
 import Utility.FileSystemEncoding as X
+import Utility.PosixFiles as X
 
 import Utility.PartialPrelude as X
